@@ -37,7 +37,7 @@ from glchess.defaults import *
 # It should really just throw ImportError
 try:
     import gtk.gtkgl
-    import OpenGL
+    import OpenGL.GL
 except (ImportError, RuntimeError):
     haveGLSupport = False
 else:
